==> kstars-16.11.90.tar.xz: kstars-16.11.90/kstars/skycomponents/horizontalcoordinategrid.h <==
/***************************************************************************
                      horizontalcoordinategrid.h  -  K Desktop Planetarium
                             -------------------
    begin                : Tue 01 Mar 2012
    copyright            : (C) 2012 by Jerome SONRIER
    email                : jsid@emor3j.fr.eu.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef HORIZONTALCOORDINATEGRID_H
#define HORIZONTALCOORDINATEGRID_H

#include "coordinategrid.h"

/**
	*@class HorizontalCoordinateGrid
	*Collection of all the circles in the horizontal coordinate grid

	*@author Jérôme SONRIER
	*@version 0.1
	*/
class HorizontalCoordinateGrid : public CoordinateGrid
{
public:
    /**
    	*@short Constructor
    	*Simply adds all of the coordinate grid circles 
    	*(meridians and parallels)
    	*@p parent Pointer to the parent SkyComposite object
    	*/
    explicit HorizontalCoordinateGrid( SkyComposite *parent );

    void preDraw( SkyPainter *skyp );
    
    void update( KSNumbers* );

    bool selected();
};


#endif

==> kstars-17.08.3.tar.xz: kstars-17.08.3/kstars/skycomponents/horizontalcoordinategrid.h <==
/***************************************************************************
                      horizontalcoordinategrid.h  -  K Desktop Planetarium
                             -------------------
    begin                : Tue 01 Mar 2012
    copyright            : (C) 2012 by Jerome SONRIER
    email                : jsid@emor3j.fr.eu.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#pragma once

#include "coordinategrid.h"

/**
 * @class HorizontalCoordinateGrid
 * Collection of all the circles in the horizontal coordinate grid
 *
 * @author Jérôme SONRIER
 * @version 0.1
 */
class HorizontalCoordinateGrid : public CoordinateGrid
{
  public:
    /**
     * @short Constructor
     * Simply adds all of the coordinate grid circles (meridians and parallels)
     * @p parent Pointer to the parent SkyComposite object
     */
    explicit HorizontalCoordinateGrid(SkyComposite *parent);

    void preDraw(SkyPainter *skyp) Q_DECL_OVERRIDE;

    void update(KSNumbers *) Q_DECL_OVERRIDE;

    bool selected() Q_DECL_OVERRIDE;
};
